"""
@Author  ：duomei
@File    ：foundry_type.py
@Time    ：2025/9/12 11:32
"""
from enum import Enum


class FoundryResourceType(Enum):
    """资源枚举类，同时包含英文标识和中文翻译"""
    AIP_PROFILE = ("AIP_PROFILE", "AIP 配置文件")
    AIP_ASSIST_WALKTHROUGH = ("AIP_ASSIST_WALKTHROUGH", "AIP 辅助引导")
    ARTIFACTS_REPOSITORY = ("ARTIFACTS_REPOSITORY", "构件仓库")
    BELLASO_CIPHER_CHANNEL = ("BELLASO_CIPHER_CHANNEL", "贝拉索密码频道")
    BELLASO_CIPHER_LICENSE = ("BELLASO_CIPHER_LICENSE", "贝拉索密码许可证")
    BLACKSMITH_DOCUMENT = ("BLACKSMITH_DOCUMENT", "铁匠文档")
    BLOBSTER_ARCHIVE = ("BLOBSTER_ARCHIVE", "Blobster 归档文件")
    BLOBSTER_AUDIO = ("BLOBSTER_AUDIO", "Blobster 音频文件")
    BLOBSTER_BLOB = ("BLOBSTER_BLOB", "Blobster 二进制大对象")
    BLOBSTER_CODE = ("BLOBSTER_CODE", "Blobster 代码文件")
    BLOBSTER_CONFIGURATION = ("BLOBSTER_CONFIGURATION", "Blobster 配置文件")
    BLOBSTER_DOCUMENT = ("BLOBSTER_DOCUMENT", "Blobster 文档")
    BLOBSTER_IMAGE = ("BLOBSTER_IMAGE", "Blobster 图像文件")
    BLOBSTER_JUPYTERNOTEBOOK = ("BLOBSTER_JUPYTERNOTEBOOK", "Blobster Jupyter 笔记本")
    BLOBSTER_PDF = ("BLOBSTER_PDF", "Blobster PDF 文件")
    BLOBSTER_PRESENTATION = ("BLOBSTER_PRESENTATION", "Blobster 演示文稿")
    BLOBSTER_SPREADSHEET = ("BLOBSTER_SPREADSHEET", "Blobster 电子表格")
    BLOBSTER_VIDEO = ("BLOBSTER_VIDEO", "Blobster 视频文件")
    BLOBSTER_XML = ("BLOBSTER_XML", "Blobster XML 文件")
    CARBON_WORKSPACE = ("CARBON_WORKSPACE", "Carbon 工作空间")
    COMPASS_FOLDER = ("COMPASS_FOLDER", "Compass 文件夹")
    COMPASS_WEB_LINK = ("COMPASS_WEB_LINK", "Compass 网页链接")
    CONTOUR_ANALYSIS = ("CONTOUR_ANALYSIS", "轮廓分析")
    DATA_HEALTH_MONITORING_VIEW = ("DATA_HEALTH_MONITORING_VIEW", "数据健康监控视图")
    DECISIONS_EXPLORATION = ("DECISIONS_EXPLORATION", "决策探索")
    DREDDIE_PIPELINE = ("DREDDIE_PIPELINE", "Dreddie 流水线")
    EDDIE_LOGIC = ("EDDIE_LOGIC", "Eddie 逻辑")
    EDDIE_PIPELINE = ("EDDIE_PIPELINE", "Eddie 流水线")
    FFORMS_FORM = ("FFORMS_FORM", "FForms 表单")
    FLOW_WORKFLOW = ("FLOW_WORKFLOW", "Flow 工作流")
    FOUNDRY_DATASET = ("FOUNDRY_DATASET", "Foundry 数据集")
    FOUNDRY_DEPLOYED_APP = ("FOUNDRY_DEPLOYED_APP", "Foundry 已部署应用")
    FOUNDRY_ACADEMY_TUTORIAL = ("FOUNDRY_ACADEMY_TUTORIAL", "Foundry 学院教程")
    FOUNDRY_CONTAINER_SERVICE_CONTAINER = ("FOUNDRY_CONTAINER_SERVICE_CONTAINER", "Foundry 容器服务容器")
    FOUNDRY_ML_OBJECTIVE = ("FOUNDRY_ML_OBJECTIVE", "Foundry 机器学习目标")
    FOUNDRY_TEMPLATES_TEMPLATE = ("FOUNDRY_TEMPLATES_TEMPLATE", "Foundry 模板（模板文件）")
    FUSION_DOCUMENT = ("FUSION_DOCUMENT", "Fusion 文档")
    GPS_VIEW = ("GPS_VIEW", "GPS 视图")
    HUBBLE_EXPLORATION_LAYOUT = ("HUBBLE_EXPLORATION_LAYOUT", "Hubble 探索布局")
    HYPERAUTO_INTEGRATION = ("HYPERAUTO_INTEGRATION", "HyperAuto 集成")
    LOGIC_FLOWS_CONNECTED_FLOW = ("LOGIC_FLOWS_CONNECTED_FLOW", "Logic Flows 关联流")
    MACHINERY_DOCUMENT = ("MACHINERY_DOCUMENT", "机械文档")
    MAGRITTE_AGENT = ("MAGRITTE_AGENT", "马格里特代理")
    MAGRITTE_DRIVER = ("MAGRITTE_DRIVER", "马格里特驱动程序")
    MAGRITTE_SOURCE = ("MAGRITTE_SOURCE", "马格里特数据源")
    MARKETPLACE_BLOCK_SET_INSTALLATION = ("MARKETPLACE_BLOCK_SET_INSTALLATION", "Marketplace 块集安装")
    MARKETPLACE_BLOCK_SET_REPO = ("MARKETPLACE_BLOCK_SET_REPO", "Marketplace 块集仓库")
    MARKETPLACE_LOCAL = ("MARKETPLACE_LOCAL", "本地 Marketplace")
    MARKETPLACE_REMOTE_STORE = ("MARKETPLACE_REMOTE_STORE", "Marketplace 远程存储")
    MIO_MEDIA_SET = ("MIO_MEDIA_SET", "MIO 媒体集")
    MODELS_MODEL = ("MODELS_MODEL", "模型（模型文件）")
    MODELS_MODEL_VERSION = ("MODELS_MODEL_VERSION", "模型版本")
    MONOCLE_GRAPH = ("MONOCLE_GRAPH", "Monocle 图表")
    NOTEPAD_NOTEPAD = ("NOTEPAD_NOTEPAD", "记事本（记事本文件）")
    NOTEPAD_NOTEPAD_TEMPLATE = ("NOTEPAD_NOTEPAD_TEMPLATE", "记事本模板")
    OBJECT_SENTINEL_MONITOR = ("OBJECT_SENTINEL_MONITOR", "对象哨兵监控")
    OBJECT_SET_VERSIONED_OBJECT_SET = ("OBJECT_SET_VERSIONED_OBJECT_SET", "对象集（带版本的对象集）")
    OPUS_GRAPH = ("OPUS_GRAPH", "Opus 图表")
    OPUS_GRAPH_TEMPLATE = ("OPUS_GRAPH_TEMPLATE", "Opus 图表模板")
    OPUS_MAP = ("OPUS_MAP", "Opus 地图")
    OPUS_MAP_LAYER = ("OPUS_MAP_LAYER", "Opus 地图图层")
    OPUS_MAP_TEMPLATE = ("OPUS_MAP_TEMPLATE", "Opus 地图模板")
    OPUS_SEARCH_AROUND = ("OPUS_SEARCH_AROUND", "Opus 周边搜索")
    QUIVER_ANALYSIS = ("QUIVER_ANALYSIS", "Quiver 分析")
    QUIVER_ARTIFACT = ("QUIVER_ARTIFACT", "Quiver 构件")
    QUIVER_DASHBOARD = ("QUIVER_DASHBOARD", "Quiver 仪表盘")
    REPORT_REPORT = ("REPORT_REPORT", "报告（报告文件）")
    SLATE_DOCUMENT = ("SLATE_DOCUMENT", "Slate 文档")
    SOLUTION_DESIGN_DIAGRAM = ("SOLUTION_DESIGN_DIAGRAM", "解决方案设计图")
    STEMMA_REPOSITORY = ("STEMMA_REPOSITORY", "Stemma 仓库")
    TABLES_TABLE = ("TABLES_TABLE", "表格（表格文件）")
    TAURUS_WORKFLOW = ("TAURUS_WORKFLOW", "Taurus 工作流")
    THIRD_PARTY_APPLICATIONS_APPLICATION = ("THIRD_PARTY_APPLICATIONS_APPLICATION", "第三方应用（应用程序）")
    TIME_SERIES_CATALOG_SYNC = ("TIME_SERIES_CATALOG_SYNC", "时间序列目录同步")
    VECTOR_TEMPLATE = ("VECTOR_TEMPLATE", "Vector 模板")
    VECTOR_WORKBOOK = ("VECTOR_WORKBOOK", "Vector 工作簿")
    WORKSHOP_MODULE = ("WORKSHOP_MODULE", "Workshop 模块")
    WORKSHOP_STATE = ("WORKSHOP_STATE", "Workshop 状态")
    CODE_REPOSITORY_FUNCTION = ("CODE_REPOSITORY_FUNCTION", "代码仓库函数")
    COMPASS_DATAEASE = ("COMPASS_DATAEASE", "dataEase")
    FOUNDRY_FLYFLOW = ("foundry_FLYFLOW", "审批流")

    @property
    def english(self):
        """返回英文标识"""
        return self.value[0]

    @property
    def chinese(self):
        """返回中文翻译"""
        return self.value[1]
